==> vst3sdk-docs-3.7.6_build_18-2-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstsdk/files.js <==
var files =
[
    [ "aaxentry.cpp", "aaxentry_8cpp.html", "aaxentry_8cpp" ],
    [ "aaxlibrary.cpp", "aaxlibrary_8cpp.html", "aaxlibrary_8cpp" ],
    [ "aaxwrapper.cpp", "aaxwrapper_8cpp.html", "aaxwrapper_8cpp" ],
    [ "aaxwrapper.h", "aaxwrapper_8h.html", null ],
    [ "aaxwrapper_description.h", "aaxwrapper__description_8h.html", null ],
    [ "aaxwrapper_gui.cpp", "aaxwrapper__gui_8cpp.html", null ],
    [ "aaxwrapper_gui.h", "aaxwrapper__gui_8h.html", null ],
    [ "aaxwrapper_parameters.cpp", "aaxwrapper__parameters_8cpp.html", "aaxwrapper__parameters_8cpp" ],
    [ "aaxwrapper_parameters.h", "aaxwrapper__parameters_8h.html", null ],
    [ "aucarbonview.h", "aucarbonview_8h.html", null ],
    [ "aucarbonview.mm", "aucarbonview_8mm.html", null ],
    [ "aucocoaview.h", "aucocoaview_8h.html", null ],
    [ "aucocoaview.mm", "aucocoaview_8mm.html", null ],
    [ "audiobuffers.h", "audiobuffers_8h.html", "audiobuffers_8h" ],
    [ "AudioIO.h", "AudioIO_8h.html", null ],
    [ "AudioIO.mm", "AudioIO_8mm.html", "AudioIO_8mm" ],
    [ "ausdk.mm", "ausdk_8mm.html", "ausdk_8mm" ],
    [ "auwrapper.h", "auwrapper_8h.html", "auwrapper_8h" ],
    [ "auwrapper.mm", "auwrapper_8mm.html", "auwrapper_8mm" ],
    [ "basewrapper.cpp", "basewrapper_8cpp.html", null ],
    [ "basewrapper.h", "basewrapper_8h.html", null ],
    [ "basewrapper.sdk.cpp", "basewrapper_8sdk_8cpp.html", null ],
    [ "connectionproxy.cpp", "connectionproxy_8cpp.html", "connectionproxy_8cpp" ],
    [ "connectionproxy.h", "connectionproxy_8h.html", [
      [ "ConnectionProxy", "classSteinberg_1_1Vst_1_1ConnectionProxy.html", "classSteinberg_1_1Vst_1_1ConnectionProxy" ]
    ] ],
    [ "doc_public_sdk.h", "doc__public__sdk_8h.html", null ],
    [ "doc_public_sdk_limited.h", "doc__public__sdk__limited_8h.html", null ],
    [ "eventlist.cpp", "eventlist_8cpp.html", "eventlist_8cpp" ],
    [ "eventlist.h", "eventlist_8h.html", null ],
    [ "HostApp.h", "HostApp_8h.html", null ],
    [ "HostApp.mm", "HostApp_8mm.html", null ],
    [ "hostclasses.cpp", "hostclasses_8cpp.html", "hostclasses_8cpp" ],
    [ "hostclasses.h", "hostclasses_8h.html", null ],
    [ "memorystream.h", "memorystream_8h.html", null ],
    [ "MidiIO.h", "MidiIO_8h.html", [
      [ "MidiIO", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO" ]
    ] ],
    [ "MidiIO.mm", "MidiIO_8mm.html", null ],
    [ "module.cpp", "module_8cpp.html", null ],
    [ "module.h", "module_8h.html", [
      [ "FactoryInfo", "classVST3_1_1Hosting_1_1FactoryInfo.html", "classVST3_1_1Hosting_1_1FactoryInfo" ],
      [ "ClassInfo", "classVST3_1_1Hosting_1_1ClassInfo.html", "classVST3_1_1Hosting_1_1ClassInfo" ],
      [ "Data", "structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html", "structVST3_1_1Hosting_1_1ClassInfo_1_1Data" ],
      [ "PluginFactory", "classVST3_1_1Hosting_1_1PluginFactory.html", "classVST3_1_1Hosting_1_1PluginFactory" ],
      [ "Module", "classVST3_1_1Hosting_1_1Module.html", "classVST3_1_1Hosting_1_1Module" ],
      [ "Snapshot", "structVST3_1_1Hosting_1_1Module_1_1Snapshot.html", "structVST3_1_1Hosting_1_1Module_1_1Snapshot" ],
      [ "ImageDesc", "structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc.html", "structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc" ]
    ] ],
    [ "module_linux.cpp", "module__linux_8cpp.html", "module__linux_8cpp" ],
    [ "module_mac.mm", "module__mac_8mm.html", "module__mac_8mm" ],
    [ "module_win32.cpp", "module__win32_8cpp.html", "module__win32_8cpp" ],
    [ "mpeprocessor.cpp", "mpeprocessor_8cpp.html", null ],
    [ "mpeprocessor.h", "mpeprocessor_8h.html", "mpeprocessor_8h" ],
    [ "NSDataIBStream.h", "NSDataIBStream_8h.html", null ],
    [ "NSDataIBStream.mm", "NSDataIBStream_8mm.html", null ],
    [ "objcclassbuilder.h", "objcclassbuilder_8h.html", [
      [ "ObjCVariable", "structSteinberg_1_1ObjCVariable.html", "structSteinberg_1_1ObjCVariable" ],
      [ "ObjCInstance", "structSteinberg_1_1ObjCInstance.html", "structSteinberg_1_1ObjCInstance" ],
      [ "ObjCClassBuilder", "structSteinberg_1_1ObjCClassBuilder.html", "structSteinberg_1_1ObjCClassBuilder" ]
    ] ],
    [ "optional.h", "optional_8h.html", [
      [ "Optional", "structVST3_1_1Optional.html", "structVST3_1_1Optional" ]
    ] ],
    [ "parameterchanges.cpp", "parameterchanges_8cpp.html", "parameterchanges_8cpp" ],
    [ "parameterchanges.h", "parameterchanges_8h.html", [
      [ "ParameterQueueValue", "structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html", "structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue" ],
      [ "ParameterChange", "structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html", "structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange" ]
    ] ],
    [ "pluginterfacesupport.cpp", "pluginterfacesupport_8cpp.html", null ],
    [ "pluginterfacesupport.h", "pluginterfacesupport_8h.html", null ],
    [ "pluginview.h", "pluginview_8h.html", null ],
    [ "plugprovider.cpp", "plugprovider_8cpp.html", null ],
    [ "plugprovider.h", "plugprovider_8h.html", [
      [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", "classSteinberg_1_1Vst_1_1PlugProvider" ],
      [ "PluginContextFactory", "classSteinberg_1_1Vst_1_1PluginContextFactory.html", "classSteinberg_1_1Vst_1_1PluginContextFactory" ]
    ] ],
    [ "PresetBrowserViewController.h", "PresetBrowserViewController_8h.html", null ],
    [ "PresetBrowserViewController.mm", "PresetBrowserViewController_8mm.html", null ],
    [ "PresetManager.h", "PresetManager_8h.html", [
      [ "PresetManager", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager" ]
    ] ],
    [ "PresetManager.mm", "PresetManager_8mm.html", null ],
    [ "PresetSaveViewController.h", "PresetSaveViewController_8h.html", null ],
    [ "PresetSaveViewController.mm", "PresetSaveViewController_8mm.html", null ],
    [ "processcontextrequirements.h", "processcontextrequirements_8h.html", [
      [ "ProcessContextRequirements", "classSteinberg_1_1Vst_1_1ProcessContextRequirements.html", "classSteinberg_1_1Vst_1_1ProcessContextRequirements" ]
    ] ],
    [ "processdata.cpp", "processdata_8cpp.html", null ],
    [ "processdata.h", "processdata_8h.html", null ],
    [ "processdataslicer.h", "processdataslicer_8h.html", [
      [ "ProcessDataSlicer", "classSteinberg_1_1Vst_1_1ProcessDataSlicer.html", "classSteinberg_1_1Vst_1_1ProcessDataSlicer" ]
    ] ],
    [ "ringbuffer.h", "ringbuffer_8h.html", [
      [ "RingBuffer", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer" ]
    ] ],
    [ "rttransfer.h", "rttransfer_8h.html", [
      [ "RTTransferT", "structSteinberg_1_1Vst_1_1RTTransferT.html", "structSteinberg_1_1Vst_1_1RTTransferT" ]
    ] ],
    [ "sampleaccurate.h", "sampleaccurate_8h.html", [
      [ "Parameter", "structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html", "structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter" ]
    ] ],
    [ "SettingsViewController.h", "SettingsViewController_8h.html", "SettingsViewController_8h" ],
    [ "SettingsViewController.mm", "SettingsViewController_8mm.html", "SettingsViewController_8mm" ],
    [ "stringconvert.cpp", "stringconvert_8cpp.html", "stringconvert_8cpp" ],
    [ "stringconvert.h", "stringconvert_8h.html", "stringconvert_8h" ],
    [ "testbase.cpp", "testbase_8cpp.html", "testbase_8cpp" ],
    [ "testbase.h", "testbase_8h.html", "testbase_8h" ],
    [ "testing.cpp", "testing_8cpp.html", "testing_8cpp" ],
    [ "testing.h", "testing_8h.html", "testing_8h" ],
    [ "uid.h", "uid_8h.html", "uid_8h" ],
    [ "usediids.cpp", "usediids_8cpp.html", null ],
    [ "versionparser.h", "versionparser_8h.html", [
      [ "Version", "structVST3_1_1Version.html", "structVST3_1_1Version" ]
    ] ],
    [ "vst2persistence.cpp", "vst2persistence_8cpp.html", "vst2persistence_8cpp" ],
    [ "vst2persistence.h", "vst2persistence_8h.html", "vst2persistence_8h" ],
    [ "vst2wrapper.cpp", "vst2wrapper_8cpp.html", "vst2wrapper_8cpp" ],
    [ "vst2wrapper.h", "vst2wrapper_8h.html", null ],
    [ "vst2wrapper.sdk.cpp", "vst2wrapper_8sdk_8cpp.html", null ],
    [ "VST3Editor.h", "VST3Editor_8h.html", null ],
    [ "VST3Editor.mm", "VST3Editor_8mm.html", null ],
    [ "VST3Plugin.h", "VST3Plugin_8h.html", null ],
    [ "VST3Plugin.mm", "VST3Plugin_8mm.html", "VST3Plugin_8mm" ],
    [ "vstaudioeffect.cpp", "vstaudioeffect_8cpp.html", null ],
    [ "vstaudioeffect.h", "vstaudioeffect_8h.html", null ],
    [ "vstaudioprocessoralgo.h", "vstaudioprocessoralgo_8h.html", "vstaudioprocessoralgo_8h" ],
    [ "vstbus.cpp", "vstbus_8cpp.html", null ],
    [ "vstbus.h", "vstbus_8h.html", null ],
    [ "vstbypassprocessor.h", "vstbypassprocessor_8h.html", "vstbypassprocessor_8h" ],
    [ "vstcomponent.cpp", "vstcomponent_8cpp.html", "vstcomponent_8cpp" ],
    [ "vstcomponent.h", "vstcomponent_8h.html", "vstcomponent_8h" ],
    [ "vstcomponentbase.cpp", "vstcomponentbase_8cpp.html", null ],
    [ "vstcomponentbase.h", "vstcomponentbase_8h.html", null ],
    [ "vsteditcontroller.cpp", "vsteditcontroller_8cpp.html", null ],
    [ "vsteditcontroller.h", "vsteditcontroller_8h.html", null ],
    [ "vsteventshelper.h", "vsteventshelper_8h.html", "vsteventshelper_8h" ],
    [ "vstgui_win32_bundle_support.cpp", "vstgui__win32__bundle__support_8cpp.html", "vstgui__win32__bundle__support_8cpp" ],
    [ "vstgui_win32_bundle_support.h", "vstgui__win32__bundle__support_8h.html", "vstgui__win32__bundle__support_8h" ],
    [ "vstguieditor.cpp", "vstguieditor_8cpp.html", "vstguieditor_8cpp" ],
    [ "vstguieditor.h", "vstguieditor_8h.html", "vstguieditor_8h" ],
    [ "vsthelpers.h", "vsthelpers_8h.html", "vsthelpers_8h" ],
    [ "vstinitiids.cpp", "vstinitiids_8cpp.html", null ],
    [ "VSTInterAppAudioAppDelegateBase.h", "VSTInterAppAudioAppDelegateBase_8h.html", [
      [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", "interfaceVSTInterAppAudioAppDelegateBase" ]
    ] ],
    [ "VSTInterAppAudioAppDelegateBase.mm", "VSTInterAppAudioAppDelegateBase_8mm.html", null ],
    [ "vstnoteexpressiontypes.cpp", "vstnoteexpressiontypes_8cpp.html", null ],
    [ "vstnoteexpressiontypes.h", "vstnoteexpressiontypes_8h.html", null ],
    [ "vstparameters.cpp", "vstparameters_8cpp.html", null ],
    [ "vstparameters.h", "vstparameters_8h.html", null ],
    [ "vstpresetfile.cpp", "vstpresetfile_8cpp.html", "vstpresetfile_8cpp" ],
    [ "vstpresetfile.h", "vstpresetfile_8h.html", "vstpresetfile_8h" ],
    [ "vstrepresentation.cpp", "vstrepresentation_8cpp.html", "vstrepresentation_8cpp" ],
    [ "vstrepresentation.h", "vstrepresentation_8h.html", null ],
    [ "vstsinglecomponenteffect.cpp", "vstsinglecomponenteffect_8cpp.html", "vstsinglecomponenteffect_8cpp" ],
    [ "vstsinglecomponenteffect.h", "vstsinglecomponenteffect_8h.html", "vstsinglecomponenteffect_8h" ],
    [ "vstspeakerarray.h", "vstspeakerarray_8h.html", [
      [ "SpeakerArray", "classSteinberg_1_1Vst_1_1SpeakerArray.html", "classSteinberg_1_1Vst_1_1SpeakerArray" ]
    ] ],
    [ "vststructsizecheck.h", "vststructsizecheck_8h.html", "vststructsizecheck_8h" ],
    [ "vsttestsuite.cpp", "vsttestsuite_8cpp.html", null ],
    [ "vsttestsuite.h", "vsttestsuite_8h.html", null ]
];

==> vst3sdk-docs-3.7.9_build_61-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstsdk/files.js <==
var files =
[
    [ "aaxentry.cpp", "aaxentry_8cpp.html", "aaxentry_8cpp" ],
    [ "aaxlibrary.cpp", "aaxlibrary_8cpp.html", "aaxlibrary_8cpp" ],
    [ "aaxwrapper.cpp", "aaxwrapper_8cpp.html", "aaxwrapper_8cpp" ],
    [ "aaxwrapper.h", "aaxwrapper_8h.html", null ],
    [ "aaxwrapper_description.h", "aaxwrapper__description_8h.html", null ],
    [ "aaxwrapper_gui.cpp", "aaxwrapper__gui_8cpp.html", null ],
    [ "aaxwrapper_gui.h", "aaxwrapper__gui_8h.html", null ],
    [ "aaxwrapper_parameters.cpp", "aaxwrapper__parameters_8cpp.html", "aaxwrapper__parameters_8cpp" ],
    [ "aaxwrapper_parameters.h", "aaxwrapper__parameters_8h.html", null ],
    [ "alignedalloc.h", "alignedalloc_8h.html", "alignedalloc_8h" ],
    [ "aucarbonview.h", "aucarbonview_8h.html", null ],
    [ "aucarbonview.mm", "aucarbonview_8mm.html", null ],
    [ "aucocoaview.h", "aucocoaview_8h.html", null ],
    [ "aucocoaview.mm", "aucocoaview_8mm.html", null ],
    [ "audiobuffers.h", "audiobuffers_8h.html", "audiobuffers_8h" ],
    [ "AudioIO.h", "AudioIO_8h.html", null ],
    [ "AudioIO.mm", "AudioIO_8mm.html", "AudioIO_8mm" ],
    [ "ausdk.mm", "ausdk_8mm.html", "ausdk_8mm" ],
    [ "auwrapper.h", "auwrapper_8h.html", "auwrapper_8h" ],
    [ "auwrapper.mm", "auwrapper_8mm.html", "auwrapper_8mm" ],
    [ "basewrapper.cpp", "basewrapper_8cpp.html", null ],
    [ "basewrapper.h", "basewrapper_8h.html", null ],
    [ "basewrapper.sdk.cpp", "basewrapper_8sdk_8cpp.html", null ],
    [ "connectionproxy.cpp", "connectionproxy_8cpp.html", "connectionproxy_8cpp" ],
    [ "connectionproxy.h", "connectionproxy_8h.html", [
      [ "ConnectionProxy", "classSteinberg_1_1Vst_1_1ConnectionProxy.html", "classSteinberg_1_1Vst_1_1ConnectionProxy" ]
    ] ],
    [ "dataexchange.cpp", "dataexchange_8cpp.html", "dataexchange_8cpp" ],
    [ "dataexchange.h", "dataexchange_8h.html", "dataexchange_8h" ],
    [ "doc_public_sdk.h", "doc__public__sdk_8h.html", null ],
    [ "doc_public_sdk_limited.h", "doc__public__sdk__limited_8h.html", null ],
    [ "eventlist.cpp", "eventlist_8cpp.html", "eventlist_8cpp" ],
    [ "eventlist.h", "eventlist_8h.html", null ],
    [ "HostApp.h", "HostApp_8h.html", null ],
    [ "HostApp.mm", "HostApp_8mm.html", null ],
    [ "hostclasses.cpp", "hostclasses_8cpp.html", "hostclasses_8cpp" ],
    [ "hostclasses.h", "hostclasses_8h.html", null ],
    [ "hostdataexchangehandler.cpp", "hostdataexchangehandler_8cpp.html", "hostdataexchangehandler_8cpp" ],
    [ "hostdataexchangehandler.h", "hostdataexchangehandler_8h.html", [
      [ "IDataExchangeHandlerHost", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html", "structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost" ],
      [ "HostDataExchangeHandler", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler.html", "structSteinberg_1_1Vst_1_1HostDataExchangeHandler" ]
    ] ],
    [ "memorystream.h", "memorystream_8h.html", null ],
    [ "MidiIO.h", "MidiIO_8h.html", [
      [ "MidiIO", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO.html", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1MidiIO" ]
    ] ],
    [ "MidiIO.mm", "MidiIO_8mm.html", null ],
    [ "module.cpp", "module_8cpp.html", null ],
    [ "module.h", "module_8h.html", [
      [ "FactoryInfo", "classVST3_1_1Hosting_1_1FactoryInfo.html", "classVST3_1_1Hosting_1_1FactoryInfo" ],
      [ "ClassInfo", "classVST3_1_1Hosting_1_1ClassInfo.html", "classVST3_1_1Hosting_1_1ClassInfo" ],
      [ "Data", "structVST3_1_1Hosting_1_1ClassInfo_1_1Data.html", "structVST3_1_1Hosting_1_1ClassInfo_1_1Data" ],
      [ "PluginFactory", "classVST3_1_1Hosting_1_1PluginFactory.html", "classVST3_1_1Hosting_1_1PluginFactory" ],
      [ "Module", "classVST3_1_1Hosting_1_1Module.html", "classVST3_1_1Hosting_1_1Module" ],
      [ "Snapshot", "structVST3_1_1Hosting_1_1Module_1_1Snapshot.html", "structVST3_1_1Hosting_1_1Module_1_1Snapshot" ],
      [ "ImageDesc", "structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc.html", "structVST3_1_1Hosting_1_1Module_1_1Snapshot_1_1ImageDesc" ]
    ] ],
    [ "module_linux.cpp", "module__linux_8cpp.html", "module__linux_8cpp" ],
    [ "module_mac.mm", "module__mac_8mm.html", "module__mac_8mm" ],
    [ "module_win32.cpp", "module__win32_8cpp.html", "module__win32_8cpp" ],
    [ "mpeprocessor.cpp", "mpeprocessor_8cpp.html", null ],
    [ "mpeprocessor.h", "mpeprocessor_8h.html", "mpeprocessor_8h" ],
    [ "NSDataIBStream.h", "NSDataIBStream_8h.html", null ],
    [ "NSDataIBStream.mm", "NSDataIBStream_8mm.html", null ],
    [ "objcclassbuilder.h", "objcclassbuilder_8h.html", [
      [ "ObjCVariable", "structSteinberg_1_1ObjCVariable.html", "structSteinberg_1_1ObjCVariable" ],
      [ "ObjCInstance", "structSteinberg_1_1ObjCInstance.html", "structSteinberg_1_1ObjCInstance" ],
      [ "ObjCClassBuilder", "structSteinberg_1_1ObjCClassBuilder.html", "structSteinberg_1_1ObjCClassBuilder" ]
    ] ],
    [ "optional.h", "optional_8h.html", [
      [ "Optional", "structVST3_1_1Optional.html", "structVST3_1_1Optional" ]
    ] ],
    [ "parameterchanges.cpp", "parameterchanges_8cpp.html", "parameterchanges_8cpp" ],
    [ "parameterchanges.h", "parameterchanges_8h.html", [
      [ "ParameterQueueValue", "structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue.html", "structSteinberg_1_1Vst_1_1ParameterValueQueue_1_1ParameterQueueValue" ],
      [ "ParameterChange", "structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html", "structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange" ]
    ] ],
    [ "pluginterfacesupport.cpp", "pluginterfacesupport_8cpp.html", null ],
    [ "pluginterfacesupport.h", "pluginterfacesupport_8h.html", null ],
    [ "pluginview.h", "pluginview_8h.html", null ],
    [ "plugprovider.cpp", "plugprovider_8cpp.html", null ],
    [ "plugprovider.h", "plugprovider_8h.html", [
      [ "PlugProvider", "classSteinberg_1_1Vst_1_1PlugProvider.html", "classSteinberg_1_1Vst_1_1PlugProvider" ],
      [ "PluginContextFactory", "classSteinberg_1_1Vst_1_1PluginContextFactory.html", "classSteinberg_1_1Vst_1_1PluginContextFactory" ]
    ] ],
    [ "PresetBrowserViewController.h", "PresetBrowserViewController_8h.html", null ],
    [ "PresetBrowserViewController.mm", "PresetBrowserViewController_8mm.html", null ],
    [ "PresetManager.h", "PresetManager_8h.html", [
      [ "PresetManager", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html", "classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager" ]
    ] ],
    [ "PresetManager.mm", "PresetManager_8mm.html", null ],
    [ "PresetSaveViewController.h", "PresetSaveViewController_8h.html", null ],
    [ "PresetSaveViewController.mm", "PresetSaveViewController_8mm.html", null ],
    [ "processcontextrequirements.h", "processcontextrequirements_8h.html", [
      [ "ProcessContextRequirements", "classSteinberg_1_1Vst_1_1ProcessContextRequirements.html", "classSteinberg_1_1Vst_1_1ProcessContextRequirements" ]
    ] ],
    [ "processdata.cpp", "processdata_8cpp.html", null ],
    [ "processdata.h", "processdata_8h.html", null ],
    [ "processdataslicer.h", "processdataslicer_8h.html", [
      [ "ProcessDataSlicer", "classSteinberg_1_1Vst_1_1ProcessDataSlicer.html", "classSteinberg_1_1Vst_1_1ProcessDataSlicer" ]
    ] ],
    [ "ringbuffer.h", "ringbuffer_8h.html", [
      [ "RingBuffer", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html", "classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer" ]
    ] ],
    [ "rttransfer.h", "rttransfer_8h.html", [
      [ "RTTransferT", "structSteinberg_1_1Vst_1_1RTTransferT.html", "structSteinberg_1_1Vst_1_1RTTransferT" ]
    ] ],
    [ "sampleaccurate.h", "sampleaccurate_8h.html", [
      [ "Parameter", "structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html", "structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter" ]
    ] ],
    [ "SettingsViewController.h", "SettingsViewController_8h.html", "SettingsViewController_8h" ],
    [ "SettingsViewController.mm", "SettingsViewController_8mm.html", "SettingsViewController_8mm" ],
    [ "stringconvert.cpp", "stringconvert_8cpp.html", "stringconvert_8cpp" ],
    [ "stringconvert.h", "stringconvert_8h.html", "stringconvert_8h" ],
    [ "systemtime.cpp", "systemtime_8cpp.html", null ],
    [ "systemtime.h", "systemtime_8h.html", [
      [ "SystemTime", "classSteinberg_1_1Vst_1_1SystemTime.html", "classSteinberg_1_1Vst_1_1SystemTime" ]
    ] ],
    [ "testbase.cpp", "testbase_8cpp.html", "testbase_8cpp" ],
    [ "testbase.h", "testbase_8h.html", "testbase_8h" ],
    [ "testing.cpp", "testing_8cpp.html", "testing_8cpp" ],
    [ "testing.h", "testing_8h.html", "testing_8h" ],
    [ "uid.h", "uid_8h.html", "uid_8h" ],
    [ "usediids.cpp", "usediids_8cpp.html", null ],
    [ "versionparser.h", "versionparser_8h.html", [
      [ "Version", "structVST3_1_1Version.html", "structVST3_1_1Version" ]
    ] ],
    [ "vst2persistence.cpp", "vst2persistence_8cpp.html", "vst2persistence_8cpp" ],
    [ "vst2persistence.h", "vst2persistence_8h.html", "vst2persistence_8h" ],
    [ "vst2wrapper.cpp", "vst2wrapper_8cpp.html", "vst2wrapper_8cpp" ],
    [ "vst2wrapper.h", "vst2wrapper_8h.html", null ],
    [ "vst2wrapper.sdk.cpp", "vst2wrapper_8sdk_8cpp.html", null ],
    [ "VST3Editor.h", "VST3Editor_8h.html", null ],
    [ "VST3Editor.mm", "VST3Editor_8mm.html", null ],
    [ "VST3Plugin.h", "VST3Plugin_8h.html", null ],
    [ "VST3Plugin.mm", "VST3Plugin_8mm.html", "VST3Plugin_8mm" ],
    [ "vstaudioeffect.cpp", "vstaudioeffect_8cpp.html", null ],
    [ "vstaudioeffect.h", "vstaudioeffect_8h.html", null ],
    [ "vstaudioprocessoralgo.h", "vstaudioprocessoralgo_8h.html", "vstaudioprocessoralgo_8h" ],
    [ "vstbus.cpp", "vstbus_8cpp.html", null ],
    [ "vstbus.h", "vstbus_8h.html", null ],
    [ "vstbypassprocessor.h", "vstbypassprocessor_8h.html", "vstbypassprocessor_8h" ],
    [ "vstcomponent.cpp", "vstcomponent_8cpp.html", "vstcomponent_8cpp" ],
    [ "vstcomponent.h", "vstcomponent_8h.html", "vstcomponent_8h" ],
    [ "vstcomponentbase.cpp", "vstcomponentbase_8cpp.html", null ],
    [ "vstcomponentbase.h", "vstcomponentbase_8h.html", null ],
    [ "vsteditcontroller.cpp", "vsteditcontroller_8cpp.html", null ],
    [ "vsteditcontroller.h", "vsteditcontroller_8h.html", null ],
    [ "vsteventshelper.h", "vsteventshelper_8h.html", "vsteventshelper_8h" ],
    [ "vstgui_win32_bundle_support.cpp", "vstgui__win32__bundle__support_8cpp.html", "vstgui__win32__bundle__support_8cpp" ],
    [ "vstgui_win32_bundle_support.h", "vstgui__win32__bundle__support_8h.html", "vstgui__win32__bundle__support_8h" ],
    [ "vstguieditor.cpp", "vstguieditor_8cpp.html", "vstguieditor_8cpp" ],
    [ "vstguieditor.h", "vstguieditor_8h.html", "vstguieditor_8h" ],
    [ "vsthelpers.h", "vsthelpers_8h.html", "vsthelpers_8h" ],
    [ "vstinitiids.cpp", "vstinitiids_8cpp.html", null ],
    [ "VSTInterAppAudioAppDelegateBase.h", "VSTInterAppAudioAppDelegateBase_8h.html", [
      [ "VSTInterAppAudioAppDelegateBase", "interfaceVSTInterAppAudioAppDelegateBase.html", "interfaceVSTInterAppAudioAppDelegateBase" ]
    ] ],
    [ "VSTInterAppAudioAppDelegateBase.mm", "VSTInterAppAudioAppDelegateBase_8mm.html", null ],
    [ "vstnoteexpressiontypes.cpp", "vstnoteexpressiontypes_8cpp.html", null ],
    [ "vstnoteexpressiontypes.h", "vstnoteexpressiontypes_8h.html", null ],
    [ "vstparameters.cpp", "vstparameters_8cpp.html", null ],
    [ "vstparameters.h", "vstparameters_8h.html", null ],
    [ "vstpresetfile.cpp", "vstpresetfile_8cpp.html", "vstpresetfile_8cpp" ],
    [ "vstpresetfile.h", "vstpresetfile_8h.html", "vstpresetfile_8h" ],
    [ "vstrepresentation.cpp", "vstrepresentation_8cpp.html", "vstrepresentation_8cpp" ],
    [ "vstrepresentation.h", "vstrepresentation_8h.html", null ],
    [ "vstsinglecomponenteffect.cpp", "vstsinglecomponenteffect_8cpp.html", "vstsinglecomponenteffect_8cpp" ],
    [ "vstsinglecomponenteffect.h", "vstsinglecomponenteffect_8h.html", "vstsinglecomponenteffect_8h" ],
    [ "vstspeakerarray.h", "vstspeakerarray_8h.html", [
      [ "SpeakerArray", "classSteinberg_1_1Vst_1_1SpeakerArray.html", "classSteinberg_1_1Vst_1_1SpeakerArray" ]
    ] ],
    [ "vststructsizecheck.h", "vststructsizecheck_8h.html", "vststructsizecheck_8h" ],
    [ "vsttestsuite.cpp", "vsttestsuite_8cpp.html", null ],
    [ "vsttestsuite.h", "vsttestsuite_8h.html", null ]
];
